Class: Aws::ACM::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ACM::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-acm/client.rb
Overview
An API client for ACM. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ACM::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_tags_to_certificate(params = {}) ⇒ Struct
Adds one or more tags to an ACM certificate.
-
#delete_certificate(params = {}) ⇒ Struct
Deletes a certificate and its associated private key.
-
#describe_certificate(params = {}) ⇒ Types::DescribeCertificateResponse
Returns detailed metadata about the specified ACM certificate.
-
#export_certificate(params = {}) ⇒ Types::ExportCertificateResponse
Exports a private certificate issued by a private certificate authority (CA) or a public certificate for use anywhere.
-
#get_account_configuration(params = {}) ⇒ Types::GetAccountConfigurationResponse
Returns the account configuration options associated with an Amazon Web Services account.
-
#get_certificate(params = {}) ⇒ Types::GetCertificateResponse
Retrieves a certificate and its certificate chain.
-
#import_certificate(params = {}) ⇒ Types::ImportCertificateResponse
Imports a certificate into Certificate Manager (ACM) to use with services that are integrated with ACM.
-
#list_certificates(params = {}) ⇒ Types::ListCertificatesResponse
Retrieves a list of certificate ARNs and domain names.
-
#list_tags_for_certificate(params = {}) ⇒ Types::ListTagsForCertificateResponse
Lists the tags that have been applied to the ACM certificate.
-
#put_account_configuration(params = {}) ⇒ Struct
Adds or modifies account-level configurations in ACM.
-
#remove_tags_from_certificate(params = {}) ⇒ Struct
Remove one or more tags from an ACM certificate.
-
#renew_certificate(params = {}) ⇒ Struct
Renews an [eligible ACM certificate].
-
#request_certificate(params = {}) ⇒ Types::RequestCertificateResponse
Requests an ACM certificate for use with other Amazon Web Services services.
-
#resend_validation_email(params = {}) ⇒ Struct
Resends the email that requests domain ownership validation.
-
#revoke_certificate(params = {}) ⇒ Types::RevokeCertificateResponse
Revokes a public ACM certificate.
-
#search_certificates(params = {}) ⇒ Types::SearchCertificatesResponse
Retrieves a list of certificates matching search criteria.
-
#update_certificate_options(params = {}) ⇒ Struct
Updates a certificate.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-acm/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1958 1959 1960 |
# File 'lib/aws-sdk-acm/client.rb', line 1958 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1961 1962 1963 |
# File 'lib/aws-sdk-acm/client.rb', line 1961 def errors_module Errors end |
Instance Method Details
#add_tags_to_certificate(params = {}) ⇒ Struct
Adds one or more tags to an ACM certificate. Tags are labels that you can use to identify and organize your Amazon Web Services resources. Each tag consists of a ‘key` and an optional `value`. You specify the certificate on input by its Amazon Resource Name (ARN). You specify the tag by using a key-value pair.
You can apply a tag to just one certificate if you want to identify a specific characteristic of that certificate, or you can apply the same tag to multiple certificates if you want to filter for a common relationship among those certificates. Similarly, you can apply the same tag to multiple resources if you want to specify a relationship among those resources. For example, you can add the same tag to an ACM certificate and an Elastic Load Balancing load balancer to indicate that they are both used by the same website. For more information, see [Tagging ACM certificates].
To remove one or more tags, use the RemoveTagsFromCertificate action. To view all of the tags that have been applied to the certificate, use the ListTagsForCertificate action.
544 545 546 547 |
# File 'lib/aws-sdk-acm/client.rb', line 544 def (params = {}, = {}) req = build_request(:add_tags_to_certificate, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 |
# File 'lib/aws-sdk-acm/client.rb', line 1818 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ACM') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-acm' context[:gem_version] = '1.104.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_certificate(params = {}) ⇒ Struct
Deletes a certificate and its associated private key. If this action succeeds, the certificate is not available for use by Amazon Web Services services integrated with ACM. Deleting a certificate is eventually consistent. The may be a short delay before the certificate no longer appears in the list that can be displayed by calling the ListCertificates action or be retrieved by calling the GetCertificate action.
<note markdown=“1”> You cannot delete an ACM certificate that is being used by another Amazon Web Services service. To delete a certificate that is in use, you must first remove the certificate association using the console or the CLI for the associated service.
Deleting a certificate issued by a private certificate (CA)
has no effect on the CA. You will continue to be charged for the CA until it is deleted. For more information, see [ Deleting Your Private CA] in the *Private Certificate Authority User Guide*.
</note>
Deleting a certificate issued by a private certificate authority (CA) has no effect on the CA. You will continue to be charged for the CA until it is deleted. For more information, see [Deleting your private CA] in the *Amazon Web Services Private Certificate Authority User Guide*.
[1]: docs.aws.amazon.com/privateca/latest/userguide/PCADeleteCA.html
604 605 606 607 |
# File 'lib/aws-sdk-acm/client.rb', line 604 def delete_certificate(params = {}, = {}) req = build_request(:delete_certificate, params) req.send_request() end |
#describe_certificate(params = {}) ⇒ Types::DescribeCertificateResponse
Returns detailed metadata about the specified ACM certificate.
If you have just created a certificate using the ‘RequestCertificate` action, there is a delay of several seconds before you can retrieve information about it.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* certificate_validated
708 709 710 711 |
# File 'lib/aws-sdk-acm/client.rb', line 708 def describe_certificate(params = {}, = {}) req = build_request(:describe_certificate, params) req.send_request() end |
#export_certificate(params = {}) ⇒ Types::ExportCertificateResponse
Exports a private certificate issued by a private certificate authority (CA) or a public certificate for use anywhere. The exported file contains the certificate, the certificate chain, and the encrypted private key associated with the public key that is embedded in the certificate. For security, you must assign a passphrase for the private key when exporting it.
For information about exporting and formatting a certificate using the ACM console or CLI, see [Export a private certificate] and [Export a public certificate].
<note markdown=“1”> ACM public certificates created prior to June 17, 2025 cannot be exported.
</note>
[1]: docs.aws.amazon.com/acm/latest/userguide/export-private.html [2]: docs.aws.amazon.com/acm/latest/userguide/export-public-certificate
778 779 780 781 |
# File 'lib/aws-sdk-acm/client.rb', line 778 def export_certificate(params = {}, = {}) req = build_request(:export_certificate, params) req.send_request() end |
#get_account_configuration(params = {}) ⇒ Types::GetAccountConfigurationResponse
Returns the account configuration options associated with an Amazon Web Services account.
798 799 800 801 |
# File 'lib/aws-sdk-acm/client.rb', line 798 def get_account_configuration(params = {}, = {}) req = build_request(:get_account_configuration, params) req.send_request() end |
#get_certificate(params = {}) ⇒ Types::GetCertificateResponse
Retrieves a certificate and its certificate chain. The certificate may be either a public or private certificate issued using the ACM ‘RequestCertificate` action, or a certificate imported into ACM using the `ImportCertificate` action. The chain consists of the certificate of the issuing CA and the intermediate certificates of any other subordinate CAs. All of the certificates are base64 encoded. You can use [OpenSSL] to decode the certificates and inspect individual fields.
848 849 850 851 |
# File 'lib/aws-sdk-acm/client.rb', line 848 def get_certificate(params = {}, = {}) req = build_request(:get_certificate, params) req.send_request() end |
#import_certificate(params = {}) ⇒ Types::ImportCertificateResponse
Imports a certificate into Certificate Manager (ACM) to use with services that are integrated with ACM. Note that [integrated services] allow only certificate types and keys they support to be associated with their resources. Further, their support differs depending on whether the certificate is imported into IAM or into ACM. For more information, see the documentation for each service. For more information about importing certificates into ACM, see [Importing Certificates] in the *Certificate Manager User Guide*.
<note markdown=“1”> ACM does not provide [managed renewal] for certificates that you import.
</note>
Note the following guidelines when importing third party certificates:
-
You must enter the private key that matches the certificate you are importing.
-
The private key must be unencrypted. You cannot import a private key that is protected by a password or a passphrase.
-
The private key must be no larger than 5 KB (5,120 bytes).
-
The certificate, private key, and certificate chain must be PEM-encoded.
-
The current time must be between the ‘Not Before` and `Not After` certificate fields.
-
The ‘Issuer` field must not be empty.
-
The OCSP authority URL, if present, must not exceed 1000 characters.
-
To import a new certificate, omit the ‘CertificateArn` argument. Include this argument only when you want to replace a previously imported certificate.
-
When you import a certificate by using the CLI, you must specify the certificate, the certificate chain, and the private key by their file names preceded by ‘fileb://`. For example, you can specify a certificate saved in the `C:temp` folder as `fileb://C:tempcertificate_to_import.pem`. If you are making an HTTP or HTTPS Query request, include these arguments as BLOBs.
-
When you import a certificate by using an SDK, you must specify the certificate, the certificate chain, and the private key files in the manner required by the programming language you’re using.
-
The cryptographic algorithm of an imported certificate must match the algorithm of the signing CA. For example, if the signing CA key type is RSA, then the certificate key type must also be RSA.
This operation returns the [Amazon Resource Name (ARN)] of the imported certificate.
[1]: docs.aws.amazon.com/acm/latest/userguide/acm-services.html [2]: docs.aws.amazon.com/acm/latest/userguide/import-certificate.html [3]: docs.aws.amazon.com/acm/latest/userguide/acm-renewal.html [4]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
965 966 967 968 |
# File 'lib/aws-sdk-acm/client.rb', line 965 def import_certificate(params = {}, = {}) req = build_request(:import_certificate, params) req.send_request() end |
#list_certificates(params = {}) ⇒ Types::ListCertificatesResponse
Retrieves a list of certificate ARNs and domain names. You can request that only certificates that match a specific status be listed. You can also filter by specific attributes of the certificate. Default filtering returns only ‘RSA_2048` certificates. For more information, see Filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1060 1061 1062 1063 |
# File 'lib/aws-sdk-acm/client.rb', line 1060 def list_certificates(params = {}, = {}) req = build_request(:list_certificates, params) req.send_request() end |
#list_tags_for_certificate(params = {}) ⇒ Types::ListTagsForCertificateResponse
Lists the tags that have been applied to the ACM certificate. Use the certificate’s Amazon Resource Name (ARN) to specify the certificate. To add a tag to an ACM certificate, use the AddTagsToCertificate action. To delete a tag, use the RemoveTagsFromCertificate action.
1103 1104 1105 1106 |
# File 'lib/aws-sdk-acm/client.rb', line 1103 def (params = {}, = {}) req = build_request(:list_tags_for_certificate, params) req.send_request() end |
#put_account_configuration(params = {}) ⇒ Struct
Adds or modifies account-level configurations in ACM.
The supported configuration option is ‘DaysBeforeExpiry`. This option specifies the number of days prior to certificate expiration when ACM starts generating `EventBridge` events. ACM sends one event per day per certificate until the certificate expires. By default, accounts receive events starting 45 days before certificate expiration.
1142 1143 1144 1145 |
# File 'lib/aws-sdk-acm/client.rb', line 1142 def put_account_configuration(params = {}, = {}) req = build_request(:put_account_configuration, params) req.send_request() end |
#remove_tags_from_certificate(params = {}) ⇒ Struct
Remove one or more tags from an ACM certificate. A tag consists of a key-value pair. If you do not specify the value portion of the tag when calling this function, the tag will be removed regardless of value. If you specify a value, the tag is removed only if it is associated with the specified value.
To add tags to a certificate, use the AddTagsToCertificate action. To view all of the tags that have been applied to a specific ACM certificate, use the ListTagsForCertificate action.
1191 1192 1193 1194 |
# File 'lib/aws-sdk-acm/client.rb', line 1191 def (params = {}, = {}) req = build_request(:remove_tags_from_certificate, params) req.send_request() end |
#renew_certificate(params = {}) ⇒ Struct
Renews an [eligible ACM certificate]. In order to renew your Amazon Web Services Private CA certificates with ACM, you must first [grant the ACM service principal permission to do so]. For more information, see [Testing Managed Renewal] in the ACM User Guide.
[1]: docs.aws.amazon.com/acm/latest/userguide/managed-renewal.html [2]: docs.aws.amazon.com/privateca/latest/userguide/assign-permissions.html#PcaPermissions
1231 1232 1233 1234 |
# File 'lib/aws-sdk-acm/client.rb', line 1231 def renew_certificate(params = {}, = {}) req = build_request(:renew_certificate, params) req.send_request() end |
#request_certificate(params = {}) ⇒ Types::RequestCertificateResponse
Requests an ACM certificate for use with other Amazon Web Services services. To request an ACM certificate, you must specify a fully qualified domain name (FQDN) in the ‘DomainName` parameter. You can also specify additional FQDNs in the `SubjectAlternativeNames` parameter.
If you are requesting a private certificate, domain validation is not required. If you are requesting a public certificate, each domain name that you specify must be validated to verify that you own or control the domain. You can use [DNS validation] or [email validation]. We recommend that you use DNS validation.
<note markdown=“1”> ACM behavior differs from the [RFC 6125] specification of the certificate validation process. ACM first checks for a Subject Alternative Name, and, if it finds one, ignores the common name (CN).
</note>
After successful completion of the ‘RequestCertificate` action, there is a delay of several seconds before you can retrieve information about the new certificate.
[1]: docs.aws.amazon.com/acm/latest/userguide/gs-acm-validate-dns.html [2]: docs.aws.amazon.com/acm/latest/userguide/gs-acm-validate-email.html [3]: datatracker.ietf.org/doc/html/rfc6125#appendix-B.2
1453 1454 1455 1456 |
# File 'lib/aws-sdk-acm/client.rb', line 1453 def request_certificate(params = {}, = {}) req = build_request(:request_certificate, params) req.send_request() end |
#resend_validation_email(params = {}) ⇒ Struct
Resends the email that requests domain ownership validation. The domain owner or an authorized representative must approve the ACM certificate before it can be issued. The certificate can be approved by clicking a link in the mail to navigate to the Amazon certificate approval website and then clicking **I Approve**. However, the validation email can be blocked by spam filters. Therefore, if you do not receive the original mail, you can request that the mail be resent within 72 hours of requesting the ACM certificate. If more than 72 hours have elapsed since your original request or since your last attempt to resend validation mail, you must request a new certificate. For more information about setting up your contact email addresses, see [Configure Email for your Domain].
[1]: docs.aws.amazon.com/acm/latest/userguide/setup-email.html
1521 1522 1523 1524 |
# File 'lib/aws-sdk-acm/client.rb', line 1521 def resend_validation_email(params = {}, = {}) req = build_request(:resend_validation_email, params) req.send_request() end |
#revoke_certificate(params = {}) ⇒ Types::RevokeCertificateResponse
Revokes a public ACM certificate. You can only revoke certificates that have been previously exported.
Once a certificate is revoked, you cannot reuse the certificate. Revoking a certificate is permanent.
1560 1561 1562 1563 |
# File 'lib/aws-sdk-acm/client.rb', line 1560 def revoke_certificate(params = {}, = {}) req = build_request(:revoke_certificate, params) req.send_request() end |
#search_certificates(params = {}) ⇒ Types::SearchCertificatesResponse
Retrieves a list of certificates matching search criteria. You can filter certificates by X.509 attributes and ACM specific properties like certificate status, type and renewal eligibility. This operation provides more flexible filtering than ListCertificates by supporting complex filter statements.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1763 1764 1765 1766 |
# File 'lib/aws-sdk-acm/client.rb', line 1763 def search_certificates(params = {}, = {}) req = build_request(:search_certificates, params) req.send_request() end |
#update_certificate_options(params = {}) ⇒ Struct
Updates a certificate. You can use this function to specify whether to opt in to or out of recording your certificate in a certificate transparency log and exporting. For more information, see [ Opting Out of Certificate Transparency Logging] and [Certificate Manager Exportable Managed Certificates].
[1]: docs.aws.amazon.com/acm/latest/userguide/acm-bestpractices.html#best-practices-transparency [2]: docs.aws.amazon.com/acm/latest/userguide/acm-exportable-certificates.html
1809 1810 1811 1812 |
# File 'lib/aws-sdk-acm/client.rb', line 1809 def (params = {}, = {}) req = build_request(:update_certificate_options, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | ——————— | —————————– | ——– | ————- | | certificate_validated | #describe_certificate | 60 | 5 |
1924 1925 1926 1927 1928 |
# File 'lib/aws-sdk-acm/client.rb', line 1924 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1932 1933 1934 |
# File 'lib/aws-sdk-acm/client.rb', line 1932 def waiter_names waiters.keys end |