Class: Aws::ACM::Types::CertificateAuthority

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Note:

CertificateAuthority is a union - when making an API calls you must set exactly one of the members.

Note:

CertificateAuthority is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CertificateAuthority corresponding to the set member.

Defines the certificate authority to use for an ACME endpoint.

Defined Under Namespace

Classes: PublicCertificateAuthority, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#public_certificate_authorityTypes::PublicCertificateAuthority

Configuration for using a public certificate authority.



676
677
678
679
680
681
682
683
684
685
# File 'lib/aws-sdk-acm/types.rb', line 676

class CertificateAuthority < Struct.new(
  :public_certificate_authority,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class PublicCertificateAuthority < CertificateAuthority; end
  class Unknown < CertificateAuthority; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



676
677
678
# File 'lib/aws-sdk-acm/types.rb', line 676

def unknown
  @unknown
end