Class: Aws::ACM::Types::CertificateMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Note:

CertificateMetadata is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CertificateMetadata corresponding to the set member.

Contains metadata about a certificate. Currently supports ACM certificate metadata.

Defined Under Namespace

Classes: AcmCertificateMetadata, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acm_certificate_metadataTypes::AcmCertificateMetadata

Metadata for an ACM certificate.



1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
# File 'lib/aws-sdk-acm/types.rb', line 1013

class CertificateMetadata < Struct.new(
  :acm_certificate_metadata,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AcmCertificateMetadata < CertificateMetadata; end
  class Unknown < CertificateMetadata; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1013
1014
1015
# File 'lib/aws-sdk-acm/types.rb', line 1013

def unknown
  @unknown
end