Class: Aws::ACM::Types::CertificateOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Structure that contains options for your certificate. You can use this structure to change the domain validation method or specify whether to export your certificate.

All public certificates are recorded in a certificate transparency log. For general information, see Certificate Transparency Logging.

You can export public ACM certificates to use with Amazon Web Services services as well as outside Amazon Web Services Cloud. For more information, see Certificate Manager exportable public certificate.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_transparency_logging_preferenceString

This parameter has been deprecated. Certificate transparency logging opt-out is no longer available. All public certificates are recorded in a certificate transparency log.

Returns:

  • (String)


1061
1062
1063
1064
1065
1066
1067
# File 'lib/aws-sdk-acm/types.rb', line 1061

class CertificateOptions < Struct.new(
  :certificate_transparency_logging_preference,
  :export,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end

#exportString

You can opt in to allow the export of your certificates by specifying ENABLED. You cannot update the value of Export after the the certificate is created.

Returns:

  • (String)


1061
1062
1063
1064
1065
1066
1067
# File 'lib/aws-sdk-acm/types.rb', line 1061

class CertificateOptions < Struct.new(
  :certificate_transparency_logging_preference,
  :export,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end

#validation_methodString

The domain validation method for the certificate. To migrate from email to DNS validation, specify DNS.

Returns:

  • (String)


1061
1062
1063
1064
1065
1066
1067
# File 'lib/aws-sdk-acm/types.rb', line 1061

class CertificateOptions < Struct.new(
  :certificate_transparency_logging_preference,
  :export,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end