Class: Aws::ACM::Types::CreateAcmeExternalAccountBindingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acme_endpoint_arnString

The Amazon Resource Name (ARN) of the ACME endpoint.

Returns:

  • (String)


1449
1450
1451
1452
1453
1454
1455
1456
1457
# File 'lib/aws-sdk-acm/types.rb', line 1449

class CreateAcmeExternalAccountBindingRequest < Struct.new(
  :idempotency_token,
  :acme_endpoint_arn,
  :role_arn,
  :expiration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#expirationTypes::Expiration

The expiration configuration for the external account binding.

Returns:



1449
1450
1451
1452
1453
1454
1455
1456
1457
# File 'lib/aws-sdk-acm/types.rb', line 1449

class CreateAcmeExternalAccountBindingRequest < Struct.new(
  :idempotency_token,
  :acme_endpoint_arn,
  :role_arn,
  :expiration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idempotency_tokenString

A unique, case-sensitive identifier to ensure idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1449
1450
1451
1452
1453
1454
1455
1456
1457
# File 'lib/aws-sdk-acm/types.rb', line 1449

class CreateAcmeExternalAccountBindingRequest < Struct.new(
  :idempotency_token,
  :acme_endpoint_arn,
  :role_arn,
  :expiration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role to associate with the external account binding.

Returns:

  • (String)


1449
1450
1451
1452
1453
1454
1455
1456
1457
# File 'lib/aws-sdk-acm/types.rb', line 1449

class CreateAcmeExternalAccountBindingRequest < Struct.new(
  :idempotency_token,
  :acme_endpoint_arn,
  :role_arn,
  :expiration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

One or more tags to associate with the external account binding.

Returns:



1449
1450
1451
1452
1453
1454
1455
1456
1457
# File 'lib/aws-sdk-acm/types.rb', line 1449

class CreateAcmeExternalAccountBindingRequest < Struct.new(
  :idempotency_token,
  :acme_endpoint_arn,
  :role_arn,
  :expiration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end