Class: Aws::ACM::Types::DistinguishedName
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::DistinguishedName
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Contains X.500 distinguished name information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#common_name ⇒ String
The common name (CN) attribute.
-
#country ⇒ String
The country © attribute.
-
#custom_attributes ⇒ Array<Types::CustomAttribute>
A list of custom attributes in the distinguished name.
-
#distinguished_name_qualifier ⇒ String
The distinguished name qualifier attribute.
-
#domain_components ⇒ Array<String>
The domain component attributes.
-
#generation_qualifier ⇒ String
The generation qualifier attribute.
-
#given_name ⇒ String
The given name attribute.
-
#initials ⇒ String
The initials attribute.
-
#locality ⇒ String
The locality (L) attribute.
-
#organization ⇒ String
The organization (O) attribute.
-
#organizational_unit ⇒ String
The organizational unit (OU) attribute.
-
#pseudonym ⇒ String
The pseudonym attribute.
-
#serial_number ⇒ String
The serial number attribute.
-
#state ⇒ String
The state or province (ST) attribute.
-
#surname ⇒ String
The surname attribute.
-
#title ⇒ String
The title attribute.
Instance Attribute Details
#common_name ⇒ String
The common name (CN) attribute.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#country ⇒ String
The country © attribute.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#custom_attributes ⇒ Array<Types::CustomAttribute>
A list of custom attributes in the distinguished name. Each custom attribute contains an object identifier (OID) and its corresponding value.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#distinguished_name_qualifier ⇒ String
The distinguished name qualifier attribute.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#domain_components ⇒ Array<String>
The domain component attributes.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#generation_qualifier ⇒ String
The generation qualifier attribute.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#given_name ⇒ String
The given name attribute.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#initials ⇒ String
The initials attribute.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#locality ⇒ String
The locality (L) attribute.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#organization ⇒ String
The organization (O) attribute.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#organizational_unit ⇒ String
The organizational unit (OU) attribute.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#pseudonym ⇒ String
The pseudonym attribute.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#serial_number ⇒ String
The serial number attribute.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state or province (ST) attribute.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#surname ⇒ String
The surname attribute.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title attribute.
968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-acm/types.rb', line 968 class DistinguishedName < Struct.new( :common_name, :domain_components, :country, :custom_attributes, :distinguished_name_qualifier, :generation_qualifier, :given_name, :initials, :locality, :organization, :organizational_unit, :pseudonym, :serial_number, :state, :surname, :title) SENSITIVE = [] include Aws::Structure end |