Class: Aws::ACM::Types::DnsValidationChallenge

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Contains the CNAME record that you must add to your DNS configuration to validate domain ownership using DNS validation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_recordTypes::ResourceRecord

The CNAME record that ACM creates for DNS validation. Add this record to your DNS configuration to prove that you own or control the domain.



1851
1852
1853
1854
1855
# File 'lib/aws-sdk-acm/types.rb', line 1851

class DnsValidationChallenge < Struct.new(
  :resource_record)
  SENSITIVE = []
  include Aws::Structure
end