Class: Aws::ACM::Types::ExpiryEventsConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Object containing expiration events options associated with an Amazon Web Services account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#days_before_expiryInteger

Specifies the number of days prior to certificate expiration when ACM starts generating EventBridge events. ACM sends one event per day per certificate until the certificate expires. By default, accounts receive events starting 45 days before certificate expiration.

Returns:

  • (Integer)


1989
1990
1991
1992
1993
# File 'lib/aws-sdk-acm/types.rb', line 1989

class ExpiryEventsConfiguration < Struct.new(
  :days_before_expiry)
  SENSITIVE = []
  include Aws::Structure
end