Class: Aws::ACM::Types::ExportCertificateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:passphrase]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_arnString

An Amazon Resource Name (ARN) of the issued certificate. This must be of the form:

arn:aws:acm:region:account:certificate/12345678-1234-1234-1234-123456789012

Returns:

  • (String)


2020
2021
2022
2023
2024
2025
# File 'lib/aws-sdk-acm/types.rb', line 2020

class ExportCertificateRequest < Struct.new(
  :certificate_arn,
  :passphrase)
  SENSITIVE = [:passphrase]
  include Aws::Structure
end

#passphraseString

Passphrase to associate with the encrypted exported private key.

When creating your passphrase, you can use any ASCII character except #, $, or %.

If you want to later decrypt the private key, you must have the passphrase. You can use the following OpenSSL command to decrypt a private key. After entering the command, you are prompted for the passphrase.

openssl rsa -in encrypted_key.pem -out decrypted_key.pem

Returns:

  • (String)


2020
2021
2022
2023
2024
2025
# File 'lib/aws-sdk-acm/types.rb', line 2020

class ExportCertificateRequest < Struct.new(
  :certificate_arn,
  :passphrase)
  SENSITIVE = [:passphrase]
  include Aws::Structure
end