Class: Aws::ACM::Types::GeneralName
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::GeneralName
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
GeneralName is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of GeneralName corresponding to the set member.
Describes an ASN.1 X.400 GeneralName as defined in RFC 5280.
Only one of the following naming options should be provided.
Defined Under Namespace
Classes: DirectoryName, DnsName, IpAddress, OtherName, RegisteredId, Rfc822Name, UniformResourceIdentifier, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#directory_name ⇒ Types::DistinguishedName
Contains information about the certificate subject.
-
#dns_name ⇒ String
Represents
GeneralNameas a DNS name. -
#ip_address ⇒ String
Represents
GeneralNameas an IPv4 or IPv6 address. -
#other_name ⇒ Types::OtherName
Represents
GeneralNameusing anOtherNameobject. -
#registered_id ⇒ String
Represents
GeneralNameas an object identifier (OID). -
#rfc_822_name ⇒ String
Represents
GeneralNameas an [RFC 822][1] email address. -
#uniform_resource_identifier ⇒ String
Represents
GeneralNameas a URI. -
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#directory_name ⇒ Types::DistinguishedName
Contains information about the certificate subject. The Subject
field in the certificate identifies the entity that owns or controls
the public key in the certificate. The entity can be a user,
computer, device, or service. The Subject must contain an X.500
distinguished name (DN). A DN is a sequence of relative
distinguished names (RDNs). The RDNs are separated by commas in the
certificate.
2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 |
# File 'lib/aws-sdk-acm/types.rb', line 2313 class GeneralName < Struct.new( :directory_name, :dns_name, :ip_address, :other_name, :registered_id, :rfc_822_name, :uniform_resource_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectoryName < GeneralName; end class DnsName < GeneralName; end class IpAddress < GeneralName; end class OtherName < GeneralName; end class RegisteredId < GeneralName; end class Rfc822Name < GeneralName; end class UniformResourceIdentifier < GeneralName; end class Unknown < GeneralName; end end |
#dns_name ⇒ String
Represents GeneralName as a DNS name.
2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 |
# File 'lib/aws-sdk-acm/types.rb', line 2313 class GeneralName < Struct.new( :directory_name, :dns_name, :ip_address, :other_name, :registered_id, :rfc_822_name, :uniform_resource_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectoryName < GeneralName; end class DnsName < GeneralName; end class IpAddress < GeneralName; end class OtherName < GeneralName; end class RegisteredId < GeneralName; end class Rfc822Name < GeneralName; end class UniformResourceIdentifier < GeneralName; end class Unknown < GeneralName; end end |
#ip_address ⇒ String
Represents GeneralName as an IPv4 or IPv6 address.
2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 |
# File 'lib/aws-sdk-acm/types.rb', line 2313 class GeneralName < Struct.new( :directory_name, :dns_name, :ip_address, :other_name, :registered_id, :rfc_822_name, :uniform_resource_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectoryName < GeneralName; end class DnsName < GeneralName; end class IpAddress < GeneralName; end class OtherName < GeneralName; end class RegisteredId < GeneralName; end class Rfc822Name < GeneralName; end class UniformResourceIdentifier < GeneralName; end class Unknown < GeneralName; end end |
#other_name ⇒ Types::OtherName
Represents GeneralName using an OtherName object.
2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 |
# File 'lib/aws-sdk-acm/types.rb', line 2313 class GeneralName < Struct.new( :directory_name, :dns_name, :ip_address, :other_name, :registered_id, :rfc_822_name, :uniform_resource_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectoryName < GeneralName; end class DnsName < GeneralName; end class IpAddress < GeneralName; end class OtherName < GeneralName; end class RegisteredId < GeneralName; end class Rfc822Name < GeneralName; end class UniformResourceIdentifier < GeneralName; end class Unknown < GeneralName; end end |
#registered_id ⇒ String
Represents GeneralName as an object identifier (OID).
2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 |
# File 'lib/aws-sdk-acm/types.rb', line 2313 class GeneralName < Struct.new( :directory_name, :dns_name, :ip_address, :other_name, :registered_id, :rfc_822_name, :uniform_resource_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectoryName < GeneralName; end class DnsName < GeneralName; end class IpAddress < GeneralName; end class OtherName < GeneralName; end class RegisteredId < GeneralName; end class Rfc822Name < GeneralName; end class UniformResourceIdentifier < GeneralName; end class Unknown < GeneralName; end end |
#rfc_822_name ⇒ String
Represents GeneralName as an RFC 822 email address.
2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 |
# File 'lib/aws-sdk-acm/types.rb', line 2313 class GeneralName < Struct.new( :directory_name, :dns_name, :ip_address, :other_name, :registered_id, :rfc_822_name, :uniform_resource_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectoryName < GeneralName; end class DnsName < GeneralName; end class IpAddress < GeneralName; end class OtherName < GeneralName; end class RegisteredId < GeneralName; end class Rfc822Name < GeneralName; end class UniformResourceIdentifier < GeneralName; end class Unknown < GeneralName; end end |
#uniform_resource_identifier ⇒ String
Represents GeneralName as a URI.
2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 |
# File 'lib/aws-sdk-acm/types.rb', line 2313 class GeneralName < Struct.new( :directory_name, :dns_name, :ip_address, :other_name, :registered_id, :rfc_822_name, :uniform_resource_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectoryName < GeneralName; end class DnsName < GeneralName; end class IpAddress < GeneralName; end class OtherName < GeneralName; end class RegisteredId < GeneralName; end class Rfc822Name < GeneralName; end class UniformResourceIdentifier < GeneralName; end class Unknown < GeneralName; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2313 2314 2315 |
# File 'lib/aws-sdk-acm/types.rb', line 2313 def unknown @unknown end |