Class: Aws::ACM::Types::GetCertificateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::GetCertificateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate ⇒ String
The ACM-issued certificate corresponding to the ARN specified as input.
-
#certificate_chain ⇒ String
Certificates forming the requested certificate's chain of trust.
Instance Attribute Details
#certificate ⇒ String
The ACM-issued certificate corresponding to the ARN specified as input.
2305 2306 2307 2308 2309 2310 |
# File 'lib/aws-sdk-acm/types.rb', line 2305 class GetCertificateResponse < Struct.new( :certificate, :certificate_chain) SENSITIVE = [] include Aws::Structure end |
#certificate_chain ⇒ String
Certificates forming the requested certificate's chain of trust. The chain consists of the certificate of the issuing CA and the intermediate certificates of any other subordinate CAs.
2305 2306 2307 2308 2309 2310 |
# File 'lib/aws-sdk-acm/types.rb', line 2305 class GetCertificateResponse < Struct.new( :certificate, :certificate_chain) SENSITIVE = [] include Aws::Structure end |