Class: Aws::ACM::Types::ImportCertificateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:private_key]

Instance Attribute Summary collapse

Instance Attribute Details

#certificateString

The certificate to import.

Returns:

  • (String)


2366
2367
2368
2369
2370
2371
2372
2373
2374
# File 'lib/aws-sdk-acm/types.rb', line 2366

class ImportCertificateRequest < Struct.new(
  :certificate_arn,
  :certificate,
  :private_key,
  :certificate_chain,
  :tags)
  SENSITIVE = [:private_key]
  include Aws::Structure
end

#certificate_arnString

The Amazon Resource Name (ARN) of an imported certificate to replace. To import a new certificate, omit this field.

Returns:

  • (String)


2366
2367
2368
2369
2370
2371
2372
2373
2374
# File 'lib/aws-sdk-acm/types.rb', line 2366

class ImportCertificateRequest < Struct.new(
  :certificate_arn,
  :certificate,
  :private_key,
  :certificate_chain,
  :tags)
  SENSITIVE = [:private_key]
  include Aws::Structure
end

#certificate_chainString

The PEM encoded certificate chain.

Returns:

  • (String)


2366
2367
2368
2369
2370
2371
2372
2373
2374
# File 'lib/aws-sdk-acm/types.rb', line 2366

class ImportCertificateRequest < Struct.new(
  :certificate_arn,
  :certificate,
  :private_key,
  :certificate_chain,
  :tags)
  SENSITIVE = [:private_key]
  include Aws::Structure
end

#private_keyString

The private key that matches the public key in the certificate.

Returns:

  • (String)


2366
2367
2368
2369
2370
2371
2372
2373
2374
# File 'lib/aws-sdk-acm/types.rb', line 2366

class ImportCertificateRequest < Struct.new(
  :certificate_arn,
  :certificate,
  :private_key,
  :certificate_chain,
  :tags)
  SENSITIVE = [:private_key]
  include Aws::Structure
end

#tagsArray<Types::Tag>

One or more resource tags to associate with the imported certificate.

Note: You cannot apply tags when reimporting a certificate.

Returns:



2366
2367
2368
2369
2370
2371
2372
2373
2374
# File 'lib/aws-sdk-acm/types.rb', line 2366

class ImportCertificateRequest < Struct.new(
  :certificate_arn,
  :certificate,
  :private_key,
  :certificate_chain,
  :tags)
  SENSITIVE = [:private_key]
  include Aws::Structure
end