Class: Aws::ACM::Types::ListCertificateDomainValidationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_arnString

The Amazon Resource Name (ARN) of the certificate for which to list domain validation summaries.

Returns:

  • (String)


2792
2793
2794
2795
2796
2797
2798
# File 'lib/aws-sdk-acm/types.rb', line 2792

class ListCertificateDomainValidationsRequest < Struct.new(
  :certificate_arn,
  :next_token,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of domain validation summaries to return. If you don't specify a value, the default is 1000.

Returns:

  • (Integer)


2792
2793
2794
2795
2796
2797
2798
# File 'lib/aws-sdk-acm/types.rb', line 2792

class ListCertificateDomainValidationsRequest < Struct.new(
  :certificate_arn,
  :next_token,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token returned by a previous call to ListCertificateDomainValidations. If the number of results exceeds MaxItems, use this token to retrieve the next page of results.

Returns:

  • (String)


2792
2793
2794
2795
2796
2797
2798
# File 'lib/aws-sdk-acm/types.rb', line 2792

class ListCertificateDomainValidationsRequest < Struct.new(
  :certificate_arn,
  :next_token,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end