Class: Aws::ACM::Types::ListCertificateDomainValidationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_validation_summary_listArray<Types::DomainValidationSummary>

A list of DomainValidationSummary objects, one for each domain on the certificate. Each object contains the domain name and its active and requested validation configurations.

Returns:



2815
2816
2817
2818
2819
2820
# File 'lib/aws-sdk-acm/types.rb', line 2815

class ListCertificateDomainValidationsResponse < Struct.new(
  :domain_validation_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the number of results exceeds MaxItems, this token is included in the response. Use this token in a subsequent ListCertificateDomainValidations request to retrieve the next page of results.

Returns:

  • (String)


2815
2816
2817
2818
2819
2820
# File 'lib/aws-sdk-acm/types.rb', line 2815

class ListCertificateDomainValidationsResponse < Struct.new(
  :domain_validation_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end