Class: Aws::ACM::Types::ListCertificatesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_key_pair_originsArray<String>

Filter the certificate list by certificate key pair origin. Specify one or more CertificateKeyPairOrigin values. Default filtering returns only certificates with key pair origin of AWS_MANAGED and CUSTOMER_PROVIDED.

Returns:



2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
# File 'lib/aws-sdk-acm/types.rb', line 2865

class ListCertificatesRequest < Struct.new(
  :certificate_statuses,
  :certificate_key_pair_origins,
  :includes,
  :next_token,
  :max_items,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_statusesArray<String>

Filter the certificate list by status value.

Returns:



2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
# File 'lib/aws-sdk-acm/types.rb', line 2865

class ListCertificatesRequest < Struct.new(
  :certificate_statuses,
  :certificate_key_pair_origins,
  :includes,
  :next_token,
  :max_items,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#includesTypes::Filters

Filter the certificate list. For more information, see the Filters structure.

Returns:



2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
# File 'lib/aws-sdk-acm/types.rb', line 2865

class ListCertificatesRequest < Struct.new(
  :certificate_statuses,
  :certificate_key_pair_origins,
  :includes,
  :next_token,
  :max_items,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

Use this parameter when paginating results to specify the maximum number of items to return in the response. If additional items exist beyond the number you specify, the NextToken element is sent in the response. Use this NextToken value in a subsequent request to retrieve additional items.

Returns:



2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
# File 'lib/aws-sdk-acm/types.rb', line 2865

class ListCertificatesRequest < Struct.new(
  :certificate_statuses,
  :certificate_key_pair_origins,
  :includes,
  :next_token,
  :max_items,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Use this parameter only when paginating results and only in a subsequent request after you receive a response with truncated results. Set it to the value of NextToken from the response you just received.

Returns:



2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
# File 'lib/aws-sdk-acm/types.rb', line 2865

class ListCertificatesRequest < Struct.new(
  :certificate_statuses,
  :certificate_key_pair_origins,
  :includes,
  :next_token,
  :max_items,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

Specifies the field to sort results by. If you specify SortBy, you must also specify SortOrder.

Returns:



2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
# File 'lib/aws-sdk-acm/types.rb', line 2865

class ListCertificatesRequest < Struct.new(
  :certificate_statuses,
  :certificate_key_pair_origins,
  :includes,
  :next_token,
  :max_items,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

Specifies the order of sorted results. If you specify SortOrder, you must also specify SortBy.

Returns:



2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
# File 'lib/aws-sdk-acm/types.rb', line 2865

class ListCertificatesRequest < Struct.new(
  :certificate_statuses,
  :certificate_key_pair_origins,
  :includes,
  :next_token,
  :max_items,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end