Class: Aws::ACM::Types::PublicCertificateAuthority
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::PublicCertificateAuthority
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Configuration for a public certificate authority.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_key_algorithms ⇒ Array<String>
The key algorithms allowed for certificates issued by this certificate authority.
Instance Attribute Details
#allowed_key_algorithms ⇒ Array<String>
The key algorithms allowed for certificates issued by this certificate authority.
2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-acm/types.rb', line 2875 class PublicCertificateAuthority < Struct.new( :allowed_key_algorithms) SENSITIVE = [] include Aws::Structure end |