Class: Aws::ACM::Types::ResendValidationEmailRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::ResendValidationEmailRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
String that contains the ARN of the requested certificate.
-
#domain ⇒ String
The fully qualified domain name (FQDN) of the certificate that needs to be validated.
-
#validation_domain ⇒ String
The base validation domain that will act as the suffix of the email addresses that are used to send the emails.
Instance Attribute Details
#certificate_arn ⇒ String
String that contains the ARN of the requested certificate. The certificate ARN is generated and returned by the RequestCertificate action as soon as the request is made. By default, using this parameter causes email to be sent to all top-level domains you specified in the certificate request. The ARN must be of the form:
‘arn:aws:acm:us-east-1:123456789012:certificate/12345678-1234-1234-1234-123456789012`
2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/aws-sdk-acm/types.rb', line 2078 class ResendValidationEmailRequest < Struct.new( :certificate_arn, :domain, :validation_domain) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The fully qualified domain name (FQDN) of the certificate that needs to be validated.
2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/aws-sdk-acm/types.rb', line 2078 class ResendValidationEmailRequest < Struct.new( :certificate_arn, :domain, :validation_domain) SENSITIVE = [] include Aws::Structure end |
#validation_domain ⇒ String
The base validation domain that will act as the suffix of the email addresses that are used to send the emails. This must be the same as the ‘Domain` value or a superdomain of the `Domain` value. For example, if you requested a certificate for `site.subdomain.example.com` and specify a ValidationDomain of `subdomain.example.com`, ACM sends email to the the following five addresses:
-
admin@subdomain.example.com
-
administrator@subdomain.example.com
-
hostmaster@subdomain.example.com
-
postmaster@subdomain.example.com
-
webmaster@subdomain.example.com
2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/aws-sdk-acm/types.rb', line 2078 class ResendValidationEmailRequest < Struct.new( :certificate_arn, :domain, :validation_domain) SENSITIVE = [] include Aws::Structure end |