Class: Aws::ACM::Types::SearchCertificatesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

When the list is truncated, this value is present and contains the value to use for the NextToken parameter in a subsequent pagination request.

Returns:

  • (String)


3578
3579
3580
3581
3582
3583
# File 'lib/aws-sdk-acm/types.rb', line 3578

class SearchCertificatesResponse < Struct.new(
  :results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#resultsArray<Types::CertificateSearchResult>

A list of certificate search results containing certificate ARNs, X.509 attributes, and ACM metadata.

Returns:



3578
3579
3580
3581
3582
3583
# File 'lib/aws-sdk-acm/types.rb', line 3578

class SearchCertificatesResponse < Struct.new(
  :results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end