Class: Aws::ACM::Types::ThrottlingException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

The request was denied because it exceeded a quota.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


2324
2325
2326
2327
2328
2329
# File 'lib/aws-sdk-acm/types.rb', line 2324

class ThrottlingException < Struct.new(
  :message,
  :throttling_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#throttling_reasonsArray<Types::ThrottlingReason>

One or more reasons why the request was throttled.

Returns:



2324
2325
2326
2327
2328
2329
# File 'lib/aws-sdk-acm/types.rb', line 2324

class ThrottlingException < Struct.new(
  :message,
  :throttling_reasons)
  SENSITIVE = []
  include Aws::Structure
end