Class: Aws::ACM::Types::UpdateCertificateOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_arnString

ARN of the requested certificate to update. This must be of the form:

arn:aws:acm:us-east-1:account:certificate/12345678-1234-1234-1234-123456789012

Returns:

  • (String)


3844
3845
3846
3847
3848
3849
# File 'lib/aws-sdk-acm/types.rb', line 3844

class UpdateCertificateOptionsRequest < Struct.new(
  :certificate_arn,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::CertificateOptions

Use to update the options for your certificate. Currently, you can change the domain validation method or specify whether to export your certificate. For more information about migrating from email to DNS validation, see Migrate from email to DNS validation.



3844
3845
3846
3847
3848
3849
# File 'lib/aws-sdk-acm/types.rb', line 3844

class UpdateCertificateOptionsRequest < Struct.new(
  :certificate_arn,
  :options)
  SENSITIVE = []
  include Aws::Structure
end