Class: Aws::ACM::Types::UpdateSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Contains information about the most recent certificate update, such as a domain validation method migration. This structure is returned as part of the CertificateDetail response from DescribeCertificate.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_validation_method_update_summaryTypes::DomainValidationMethodUpdateSummary

Contains information about a domain validation method migration, including the previous and target validation methods.



3892
3893
3894
3895
3896
3897
3898
3899
3900
# File 'lib/aws-sdk-acm/types.rb', line 3892

class UpdateSummary < Struct.new(
  :status,
  :type,
  :domain_validation_method_update_summary,
  :requested_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#requested_atTime

The time at which the certificate update was requested.

Returns:

  • (Time)


3892
3893
3894
3895
3896
3897
3898
3899
3900
# File 'lib/aws-sdk-acm/types.rb', line 3892

class UpdateSummary < Struct.new(
  :status,
  :type,
  :domain_validation_method_update_summary,
  :requested_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the certificate update. The following are valid values:

  • PENDING_DOMAIN_VALIDATION – The certificate update is waiting for domain ownership validation to complete.

  • SUCCESS – The certificate was updated successfully.

  • FAILED – The certificate update failed.

Returns:

  • (String)


3892
3893
3894
3895
3896
3897
3898
3899
3900
# File 'lib/aws-sdk-acm/types.rb', line 3892

class UpdateSummary < Struct.new(
  :status,
  :type,
  :domain_validation_method_update_summary,
  :requested_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of update that was requested for the certificate. The following are valid values:

  • DOMAIN_VALIDATION_METHOD – The update changes the domain validation method for the certificate.

^

Returns:

  • (String)


3892
3893
3894
3895
3896
3897
3898
3899
3900
# File 'lib/aws-sdk-acm/types.rb', line 3892

class UpdateSummary < Struct.new(
  :status,
  :type,
  :domain_validation_method_update_summary,
  :requested_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The time at which the certificate update status was last changed.

Returns:

  • (Time)


3892
3893
3894
3895
3896
3897
3898
3899
3900
# File 'lib/aws-sdk-acm/types.rb', line 3892

class UpdateSummary < Struct.new(
  :status,
  :type,
  :domain_validation_method_update_summary,
  :requested_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end