Class: Aws::ACM::Types::ValidationChallenge

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Note:

ValidationChallenge is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ValidationChallenge corresponding to the set member.

Contains the challenge details that you use to prove domain ownership. Only one member is set, depending on the validation method.

Defined Under Namespace

Classes: DnsValidationChallenge, EmailValidationChallenge, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dns_validation_challengeTypes::DnsValidationChallenge

Contains the CNAME record that you must add to your DNS configuration to validate domain ownership using DNS validation.



3918
3919
3920
3921
3922
3923
3924
3925
3926
3927
3928
3929
# File 'lib/aws-sdk-acm/types.rb', line 3918

class ValidationChallenge < Struct.new(
  :email_validation_challenge,
  :dns_validation_challenge,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EmailValidationChallenge < ValidationChallenge; end
  class DnsValidationChallenge < ValidationChallenge; end
  class Unknown < ValidationChallenge; end
end

#email_validation_challengeTypes::EmailValidationChallenge

Contains the email addresses used for email-based domain validation.



3918
3919
3920
3921
3922
3923
3924
3925
3926
3927
3928
3929
# File 'lib/aws-sdk-acm/types.rb', line 3918

class ValidationChallenge < Struct.new(
  :email_validation_challenge,
  :dns_validation_challenge,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EmailValidationChallenge < ValidationChallenge; end
  class DnsValidationChallenge < ValidationChallenge; end
  class Unknown < ValidationChallenge; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



3918
3919
3920
# File 'lib/aws-sdk-acm/types.rb', line 3918

def unknown
  @unknown
end