Class: Aws::ACM::Types::X509Attributes

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Contains X.509 certificate attributes extracted from the certificate.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#extended_key_usagesArray<String>

Contains a list of Extended Key Usage X.509 v3 extension objects. Each object specifies a purpose for which the certificate public key can be used and consists of a name and an object identifier (OID).

Returns:

  • (Array<String>)


4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
# File 'lib/aws-sdk-acm/types.rb', line 4106

class X509Attributes < Struct.new(
  :issuer,
  :subject,
  :subject_alternative_names,
  :extended_key_usages,
  :key_algorithm,
  :key_usages,
  :serial_number,
  :not_after,
  :not_before)
  SENSITIVE = []
  include Aws::Structure
end

#issuerTypes::DistinguishedName

The distinguished name of the certificate issuer.



4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
# File 'lib/aws-sdk-acm/types.rb', line 4106

class X509Attributes < Struct.new(
  :issuer,
  :subject,
  :subject_alternative_names,
  :extended_key_usages,
  :key_algorithm,
  :key_usages,
  :serial_number,
  :not_after,
  :not_before)
  SENSITIVE = []
  include Aws::Structure
end

#key_algorithmString

The algorithm that was used to generate the public-private key pair.

Returns:

  • (String)


4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
# File 'lib/aws-sdk-acm/types.rb', line 4106

class X509Attributes < Struct.new(
  :issuer,
  :subject,
  :subject_alternative_names,
  :extended_key_usages,
  :key_algorithm,
  :key_usages,
  :serial_number,
  :not_after,
  :not_before)
  SENSITIVE = []
  include Aws::Structure
end

#key_usagesArray<String>

A list of Key Usage X.509 v3 extension objects. Each object is a string value that identifies the purpose of the public key contained in the certificate. Possible extension values include DIGITAL_SIGNATURE, KEY_ENCHIPHERMENT, NON_REPUDIATION, and more.

Returns:

  • (Array<String>)


4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
# File 'lib/aws-sdk-acm/types.rb', line 4106

class X509Attributes < Struct.new(
  :issuer,
  :subject,
  :subject_alternative_names,
  :extended_key_usages,
  :key_algorithm,
  :key_usages,
  :serial_number,
  :not_after,
  :not_before)
  SENSITIVE = []
  include Aws::Structure
end

#not_afterTime

The time after which the certificate is not valid.

Returns:

  • (Time)


4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
# File 'lib/aws-sdk-acm/types.rb', line 4106

class X509Attributes < Struct.new(
  :issuer,
  :subject,
  :subject_alternative_names,
  :extended_key_usages,
  :key_algorithm,
  :key_usages,
  :serial_number,
  :not_after,
  :not_before)
  SENSITIVE = []
  include Aws::Structure
end

#not_beforeTime

The time before which the certificate is not valid.

Returns:

  • (Time)


4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
# File 'lib/aws-sdk-acm/types.rb', line 4106

class X509Attributes < Struct.new(
  :issuer,
  :subject,
  :subject_alternative_names,
  :extended_key_usages,
  :key_algorithm,
  :key_usages,
  :serial_number,
  :not_after,
  :not_before)
  SENSITIVE = []
  include Aws::Structure
end

#serial_numberString

The serial number assigned by the certificate authority.

Returns:

  • (String)


4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
# File 'lib/aws-sdk-acm/types.rb', line 4106

class X509Attributes < Struct.new(
  :issuer,
  :subject,
  :subject_alternative_names,
  :extended_key_usages,
  :key_algorithm,
  :key_usages,
  :serial_number,
  :not_after,
  :not_before)
  SENSITIVE = []
  include Aws::Structure
end

#subjectTypes::DistinguishedName

The distinguished name of the certificate subject.



4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
# File 'lib/aws-sdk-acm/types.rb', line 4106

class X509Attributes < Struct.new(
  :issuer,
  :subject,
  :subject_alternative_names,
  :extended_key_usages,
  :key_algorithm,
  :key_usages,
  :serial_number,
  :not_after,
  :not_before)
  SENSITIVE = []
  include Aws::Structure
end

#subject_alternative_namesArray<Types::GeneralName>

One or more domain names (subject alternative names) included in the certificate. This list contains the domain names that are bound to the public key that is contained in the certificate. The subject alternative names include the canonical domain name (CN) of the certificate and additional domain names that can be used to connect to the website.

Returns:



4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
# File 'lib/aws-sdk-acm/types.rb', line 4106

class X509Attributes < Struct.new(
  :issuer,
  :subject,
  :subject_alternative_names,
  :extended_key_usages,
  :key_algorithm,
  :key_usages,
  :serial_number,
  :not_after,
  :not_before)
  SENSITIVE = []
  include Aws::Structure
end