Class: Aws::ACM::Waiters::AcmeDomainValidationDeleted
- Inherits:
-
Object
- Object
- Aws::ACM::Waiters::AcmeDomainValidationDeleted
- Defined in:
- lib/aws-sdk-acm/waiters.rb,
sig/waiters.rbs
Overview
Wait until an ACME domain validation has been deleted.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ AcmeDomainValidationDeleted
constructor
A new instance of AcmeDomainValidationDeleted.
-
#wait(params = {}) ⇒ Types::DescribeAcmeDomainValidationResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ AcmeDomainValidationDeleted
Returns a new instance of AcmeDomainValidationDeleted.
89 90 |
# File 'lib/aws-sdk-acm/waiters.rb', line 89
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
120 121 122 |
# File 'lib/aws-sdk-acm/waiters.rb', line 120 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeAcmeDomainValidationResponse
Returns a response object which responds to the following methods:
- #acme_domain_validation => Types::AcmeDomainValidation
115 |
# File 'lib/aws-sdk-acm/waiters.rb', line 115
def wait: (
|