Class: Aws::ACM::Waiters::CertificateValidated
- Inherits:
-
Object
- Object
- Aws::ACM::Waiters::CertificateValidated
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-acm/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ CertificateValidated
constructor
A new instance of CertificateValidated.
-
#wait(params = {}) ⇒ Types::DescribeCertificateResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ CertificateValidated
Returns a new instance of CertificateValidated.
278 279 |
# File 'lib/aws-sdk-acm/waiters.rb', line 278
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
321 322 323 |
# File 'lib/aws-sdk-acm/waiters.rb', line 321 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeCertificateResponse
Returns a response object which responds to the following methods:
- #certificate => Types::CertificateDetail
316 |
# File 'lib/aws-sdk-acm/waiters.rb', line 316
def wait: (
|