Class: Aws::ACM::Types::AcmCertificateMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::AcmCertificateMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Contains ACM-specific metadata about a certificate.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#acme_account_id ⇒ String
The ACME account identifier associated with the certificate.
-
#acme_endpoint_arn ⇒ String
The ARN of the ACME endpoint used to issue the certificate.
-
#certificate_key_pair_origin ⇒ String
The origin of the certificate's key pair.
-
#created_at ⇒ Time
The time at which the certificate was requested.
-
#export_option ⇒ String
Indicates whether the certificate can be exported.
-
#exported ⇒ Boolean
Indicates whether the certificate has been exported.
-
#imported_at ⇒ Time
The date and time when the certificate was imported.
-
#in_use ⇒ Boolean
Indicates whether the certificate is currently in use by an Amazon Web Services service.
-
#issued_at ⇒ Time
The time at which the certificate was issued.
-
#managed_by ⇒ String
Identifies the Amazon Web Services service that manages the certificate issued by ACM.
-
#renewal_eligibility ⇒ String
Specifies whether the certificate is eligible for renewal.
-
#renewal_status ⇒ String
The renewal status of the certificate.
-
#revoked_at ⇒ Time
The time at which the certificate was revoked.
-
#status ⇒ String
The status of the certificate.
-
#type ⇒ String
The source of the certificate.
-
#validation_method ⇒ String
Specifies the domain validation method.
Instance Attribute Details
#acme_account_id ⇒ String
The ACME account identifier associated with the certificate.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#acme_endpoint_arn ⇒ String
The ARN of the ACME endpoint used to issue the certificate.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#certificate_key_pair_origin ⇒ String
The origin of the certificate's key pair.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time at which the certificate was requested.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#export_option ⇒ String
Indicates whether the certificate can be exported.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#exported ⇒ Boolean
Indicates whether the certificate has been exported.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#imported_at ⇒ Time
The date and time when the certificate was imported. This value
exists only when the certificate type is IMPORTED.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#in_use ⇒ Boolean
Indicates whether the certificate is currently in use by an Amazon Web Services service.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#issued_at ⇒ Time
The time at which the certificate was issued. This value exists only
when the certificate type is AMAZON_ISSUED.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#managed_by ⇒ String
Identifies the Amazon Web Services service that manages the certificate issued by ACM.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#renewal_eligibility ⇒ String
Specifies whether the certificate is eligible for renewal. At this time, only exported private certificates can be renewed with the RenewCertificate command.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#renewal_status ⇒ String
The renewal status of the certificate.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#revoked_at ⇒ Time
The time at which the certificate was revoked. This value exists
only when the certificate status is REVOKED.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the certificate.
A certificate enters status PENDING_VALIDATION upon being requested, unless it fails for any of the reasons given in the troubleshooting topic Certificate request fails. ACM makes repeated attempts to validate a certificate for 72 hours and then times out. If a certificate shows status FAILED or VALIDATION_TIMED_OUT, delete the request, correct the issue with DNS validation or Email validation, and try again. If validation succeeds, the certificate enters status ISSUED.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The source of the certificate. For certificates provided by ACM,
this value is AMAZON_ISSUED. For certificates that you imported
with ImportCertificate, this value is IMPORTED. ACM does not
provide managed renewal for imported certificates. For more
information about the differences between certificates that you
import and those that ACM provides, see Importing Certificates
in the Certificate Manager User Guide.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |
#validation_method ⇒ String
Specifies the domain validation method.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-acm/types.rb', line 127 class AcmCertificateMetadata < Struct.new( :created_at, :exported, :imported_at, :in_use, :issued_at, :renewal_eligibility, :revoked_at, :status, :renewal_status, :type, :export_option, :managed_by, :validation_method, :certificate_key_pair_origin, :acme_endpoint_arn, :acme_account_id) SENSITIVE = [] include Aws::Structure end |