Class: Aws::ACM::Types::AcmCertificateMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Contains ACM-specific metadata about a certificate.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The time at which the certificate was requested.

Returns:

  • (Time)


115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/aws-sdk-acm/types.rb', line 115

class AcmCertificateMetadata < Struct.new(
  :created_at,
  :exported,
  :imported_at,
  :in_use,
  :issued_at,
  :renewal_eligibility,
  :revoked_at,
  :status,
  :renewal_status,
  :type,
  :export_option,
  :managed_by,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end

#export_optionString

Indicates whether the certificate can be exported.

Returns:

  • (String)


115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/aws-sdk-acm/types.rb', line 115

class AcmCertificateMetadata < Struct.new(
  :created_at,
  :exported,
  :imported_at,
  :in_use,
  :issued_at,
  :renewal_eligibility,
  :revoked_at,
  :status,
  :renewal_status,
  :type,
  :export_option,
  :managed_by,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end

#exportedBoolean

Indicates whether the certificate has been exported.

Returns:

  • (Boolean)


115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/aws-sdk-acm/types.rb', line 115

class AcmCertificateMetadata < Struct.new(
  :created_at,
  :exported,
  :imported_at,
  :in_use,
  :issued_at,
  :renewal_eligibility,
  :revoked_at,
  :status,
  :renewal_status,
  :type,
  :export_option,
  :managed_by,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end

#imported_atTime

The date and time when the certificate was imported. This value exists only when the certificate type is ‘IMPORTED`.

Returns:

  • (Time)


115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/aws-sdk-acm/types.rb', line 115

class AcmCertificateMetadata < Struct.new(
  :created_at,
  :exported,
  :imported_at,
  :in_use,
  :issued_at,
  :renewal_eligibility,
  :revoked_at,
  :status,
  :renewal_status,
  :type,
  :export_option,
  :managed_by,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end

#in_useBoolean

Indicates whether the certificate is currently in use by an Amazon Web Services service.

Returns:

  • (Boolean)


115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/aws-sdk-acm/types.rb', line 115

class AcmCertificateMetadata < Struct.new(
  :created_at,
  :exported,
  :imported_at,
  :in_use,
  :issued_at,
  :renewal_eligibility,
  :revoked_at,
  :status,
  :renewal_status,
  :type,
  :export_option,
  :managed_by,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end

#issued_atTime

The time at which the certificate was issued. This value exists only when the certificate type is ‘AMAZON_ISSUED`.

Returns:

  • (Time)


115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/aws-sdk-acm/types.rb', line 115

class AcmCertificateMetadata < Struct.new(
  :created_at,
  :exported,
  :imported_at,
  :in_use,
  :issued_at,
  :renewal_eligibility,
  :revoked_at,
  :status,
  :renewal_status,
  :type,
  :export_option,
  :managed_by,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end

#managed_byString

Identifies the Amazon Web Services service that manages the certificate issued by ACM.

Returns:

  • (String)


115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/aws-sdk-acm/types.rb', line 115

class AcmCertificateMetadata < Struct.new(
  :created_at,
  :exported,
  :imported_at,
  :in_use,
  :issued_at,
  :renewal_eligibility,
  :revoked_at,
  :status,
  :renewal_status,
  :type,
  :export_option,
  :managed_by,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end

#renewal_eligibilityString

Specifies whether the certificate is eligible for renewal. At this time, only exported private certificates can be renewed with the RenewCertificate command.

Returns:

  • (String)


115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/aws-sdk-acm/types.rb', line 115

class AcmCertificateMetadata < Struct.new(
  :created_at,
  :exported,
  :imported_at,
  :in_use,
  :issued_at,
  :renewal_eligibility,
  :revoked_at,
  :status,
  :renewal_status,
  :type,
  :export_option,
  :managed_by,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end

#renewal_statusString

The renewal status of the certificate.

Returns:

  • (String)


115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/aws-sdk-acm/types.rb', line 115

class AcmCertificateMetadata < Struct.new(
  :created_at,
  :exported,
  :imported_at,
  :in_use,
  :issued_at,
  :renewal_eligibility,
  :revoked_at,
  :status,
  :renewal_status,
  :type,
  :export_option,
  :managed_by,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end

#revoked_atTime

The time at which the certificate was revoked. This value exists only when the certificate status is ‘REVOKED`.

Returns:

  • (Time)


115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/aws-sdk-acm/types.rb', line 115

class AcmCertificateMetadata < Struct.new(
  :created_at,
  :exported,
  :imported_at,
  :in_use,
  :issued_at,
  :renewal_eligibility,
  :revoked_at,
  :status,
  :renewal_status,
  :type,
  :export_option,
  :managed_by,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the certificate.

A certificate enters status PENDING_VALIDATION upon being requested, unless it fails for any of the reasons given in the troubleshooting topic [Certificate request fails]. ACM makes repeated attempts to validate a certificate for 72 hours and then times out. If a certificate shows status FAILED or VALIDATION_TIMED_OUT, delete the request, correct the issue with

DNS validation][2

or [Email validation], and try again. If

validation succeeds, the certificate enters status ISSUED.

[1]: docs.aws.amazon.com/acm/latest/userguide/troubleshooting-failed.html [2]: docs.aws.amazon.com/acm/latest/userguide/dns-validation.html [3]: docs.aws.amazon.com/acm/latest/userguide/email-validation.html

Returns:

  • (String)


115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/aws-sdk-acm/types.rb', line 115

class AcmCertificateMetadata < Struct.new(
  :created_at,
  :exported,
  :imported_at,
  :in_use,
  :issued_at,
  :renewal_eligibility,
  :revoked_at,
  :status,
  :renewal_status,
  :type,
  :export_option,
  :managed_by,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The source of the certificate. For certificates provided by ACM, this value is ‘AMAZON_ISSUED`. For certificates that you imported with ImportCertificate, this value is `IMPORTED`. ACM does not provide [managed renewal] for imported certificates. For more information about the differences between certificates that you import and those that ACM provides, see [Importing Certificates] in the *Certificate Manager User Guide*.

[1]: docs.aws.amazon.com/acm/latest/userguide/acm-renewal.html [2]: docs.aws.amazon.com/acm/latest/userguide/import-certificate.html

Returns:

  • (String)


115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/aws-sdk-acm/types.rb', line 115

class AcmCertificateMetadata < Struct.new(
  :created_at,
  :exported,
  :imported_at,
  :in_use,
  :issued_at,
  :renewal_eligibility,
  :revoked_at,
  :status,
  :renewal_status,
  :type,
  :export_option,
  :managed_by,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end

#validation_methodString

Specifies the domain validation method.

Returns:

  • (String)


115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/aws-sdk-acm/types.rb', line 115

class AcmCertificateMetadata < Struct.new(
  :created_at,
  :exported,
  :imported_at,
  :in_use,
  :issued_at,
  :renewal_eligibility,
  :revoked_at,
  :status,
  :renewal_status,
  :type,
  :export_option,
  :managed_by,
  :validation_method)
  SENSITIVE = []
  include Aws::Structure
end