Class: Aws::ACM::Types::CertificateAuthority
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::CertificateAuthority
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Note:
CertificateAuthority is a union - when making an API calls you must set exactly one of the members.
Note:
CertificateAuthority is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CertificateAuthority corresponding to the set member.
Defines the certificate authority to use for an ACME endpoint.
Defined Under Namespace
Classes: PublicCertificateAuthority, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#public_certificate_authority ⇒ Types::PublicCertificateAuthority
Configuration for using a public certificate authority.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#public_certificate_authority ⇒ Types::PublicCertificateAuthority
Configuration for using a public certificate authority.
676 677 678 679 680 681 682 683 684 685 |
# File 'lib/aws-sdk-acm/types.rb', line 676 class CertificateAuthority < Struct.new( :public_certificate_authority, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class PublicCertificateAuthority < CertificateAuthority; end class Unknown < CertificateAuthority; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
676 677 678 |
# File 'lib/aws-sdk-acm/types.rb', line 676 def unknown @unknown end |