Class: Aws::ACM::Types::CertificateMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::CertificateMetadata
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Note:
CertificateMetadata is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CertificateMetadata corresponding to the set member.
Contains metadata about a certificate. Currently supports ACM certificate metadata.
Defined Under Namespace
Classes: AcmCertificateMetadata, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#acm_certificate_metadata ⇒ Types::AcmCertificateMetadata
Metadata for an ACM certificate.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#acm_certificate_metadata ⇒ Types::AcmCertificateMetadata
Metadata for an ACM certificate.
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 |
# File 'lib/aws-sdk-acm/types.rb', line 1006 class CertificateMetadata < Struct.new( :acm_certificate_metadata, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AcmCertificateMetadata < CertificateMetadata; end class Unknown < CertificateMetadata; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1006 1007 1008 |
# File 'lib/aws-sdk-acm/types.rb', line 1006 def unknown @unknown end |