Class: Aws::ACM::Types::CertificateOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Structure that contains options for your certificate. You can use this structure to specify whether to export your certificate.

Certificate transparency logging opt-out is no longer available. All public certificates are recorded in a certificate transparency log. For general information, see [Certificate Transparency Logging].

You can export public ACM certificates to use with Amazon Web Services services as well as outside Amazon Web Services Cloud. For more information, see [Certificate Manager exportable public certificate].

[1]: docs.aws.amazon.com/acm/latest/userguide/acm-concepts.html#concept-transparency [2]: docs.aws.amazon.com/acm/latest/userguide/acm-exportable-certificates.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_transparency_logging_preferenceString

This parameter has been deprecated. Certificate transparency logging opt-out is no longer available. All public certificates are recorded in a certificate transparency log.

Returns:

  • (String)


569
570
571
572
573
574
# File 'lib/aws-sdk-acm/types.rb', line 569

class CertificateOptions < Struct.new(
  :certificate_transparency_logging_preference,
  :export)
  SENSITIVE = []
  include Aws::Structure
end

#exportString

You can opt in to allow the export of your certificates by specifying ‘ENABLED`. You cannot update the value of `Export` after the the certificate is created.

Returns:

  • (String)


569
570
571
572
573
574
# File 'lib/aws-sdk-acm/types.rb', line 569

class CertificateOptions < Struct.new(
  :certificate_transparency_logging_preference,
  :export)
  SENSITIVE = []
  include Aws::Structure
end