Class: Aws::ACM::Types::DomainValidationMethodUpdateSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::DomainValidationMethodUpdateSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Contains information about a domain validation method migration, including the previous validation method and the target validation method.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#from ⇒ String
The validation method that the certificate was using before the update.
-
#to ⇒ String
The target validation method for the update.
Instance Attribute Details
#from ⇒ String
The validation method that the certificate was using before the update.
1967 1968 1969 1970 1971 1972 |
# File 'lib/aws-sdk-acm/types.rb', line 1967 class DomainValidationMethodUpdateSummary < Struct.new( :from, :to) SENSITIVE = [] include Aws::Structure end |
#to ⇒ String
The target validation method for the update.
1967 1968 1969 1970 1971 1972 |
# File 'lib/aws-sdk-acm/types.rb', line 1967 class DomainValidationMethodUpdateSummary < Struct.new( :from, :to) SENSITIVE = [] include Aws::Structure end |