Class: Aws::ACM::Types::ExportCertificateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::ExportCertificateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:passphrase]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
An Amazon Resource Name (ARN) of the issued certificate.
-
#passphrase ⇒ String
Passphrase to associate with the encrypted exported private key.
Instance Attribute Details
#certificate_arn ⇒ String
An Amazon Resource Name (ARN) of the issued certificate. This must be of the form:
arn:aws:acm:region:account:certificate/12345678-1234-1234-1234-123456789012
2020 2021 2022 2023 2024 2025 |
# File 'lib/aws-sdk-acm/types.rb', line 2020 class ExportCertificateRequest < Struct.new( :certificate_arn, :passphrase) SENSITIVE = [:passphrase] include Aws::Structure end |
#passphrase ⇒ String
Passphrase to associate with the encrypted exported private key.
If you want to later decrypt the private key, you must have the passphrase. You can use the following OpenSSL command to decrypt a private key. After entering the command, you are prompted for the passphrase.
openssl rsa -in encrypted_key.pem -out decrypted_key.pem
2020 2021 2022 2023 2024 2025 |
# File 'lib/aws-sdk-acm/types.rb', line 2020 class ExportCertificateRequest < Struct.new( :certificate_arn, :passphrase) SENSITIVE = [:passphrase] include Aws::Structure end |