Class: Aws::ACM::Types::GeneralName
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::GeneralName
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
GeneralName is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of GeneralName corresponding to the set member.
Describes an ASN.1 X.400 ‘GeneralName` as defined in [RFC 5280]. Only one of the following naming options should be provided.
Direct Known Subclasses
DirectoryName, DnsName, IpAddress, OtherName, RegisteredId, Rfc822Name, UniformResourceIdentifier, Unknown
Defined Under Namespace
Classes: DirectoryName, DnsName, IpAddress, OtherName, RegisteredId, Rfc822Name, UniformResourceIdentifier, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#directory_name ⇒ Types::DistinguishedName
Contains information about the certificate subject.
-
#dns_name ⇒ String
Represents ‘GeneralName` as a DNS name.
-
#ip_address ⇒ String
Represents ‘GeneralName` as an IPv4 or IPv6 address.
-
#other_name ⇒ Types::OtherName
Represents ‘GeneralName` using an `OtherName` object.
-
#registered_id ⇒ String
Represents ‘GeneralName` as an object identifier (OID).
-
#rfc_822_name ⇒ String
Represents ‘GeneralName` as an [RFC 822] email address.
-
#uniform_resource_identifier ⇒ String
Represents ‘GeneralName` as a URI.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#directory_name ⇒ Types::DistinguishedName
Contains information about the certificate subject. The ‘Subject` field in the certificate identifies the entity that owns or controls the public key in the certificate. The entity can be a user, computer, device, or service. The `Subject` must contain an X.500 distinguished name (DN). A DN is a sequence of relative distinguished names (RDNs). The RDNs are separated by commas in the certificate.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 |
# File 'lib/aws-sdk-acm/types.rb', line 1332 class GeneralName < Struct.new( :directory_name, :dns_name, :ip_address, :other_name, :registered_id, :rfc_822_name, :uniform_resource_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectoryName < GeneralName; end class DnsName < GeneralName; end class IpAddress < GeneralName; end class OtherName < GeneralName; end class RegisteredId < GeneralName; end class Rfc822Name < GeneralName; end class UniformResourceIdentifier < GeneralName; end class Unknown < GeneralName; end end |
#dns_name ⇒ String
Represents ‘GeneralName` as a DNS name.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 |
# File 'lib/aws-sdk-acm/types.rb', line 1332 class GeneralName < Struct.new( :directory_name, :dns_name, :ip_address, :other_name, :registered_id, :rfc_822_name, :uniform_resource_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectoryName < GeneralName; end class DnsName < GeneralName; end class IpAddress < GeneralName; end class OtherName < GeneralName; end class RegisteredId < GeneralName; end class Rfc822Name < GeneralName; end class UniformResourceIdentifier < GeneralName; end class Unknown < GeneralName; end end |
#ip_address ⇒ String
Represents ‘GeneralName` as an IPv4 or IPv6 address.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 |
# File 'lib/aws-sdk-acm/types.rb', line 1332 class GeneralName < Struct.new( :directory_name, :dns_name, :ip_address, :other_name, :registered_id, :rfc_822_name, :uniform_resource_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectoryName < GeneralName; end class DnsName < GeneralName; end class IpAddress < GeneralName; end class OtherName < GeneralName; end class RegisteredId < GeneralName; end class Rfc822Name < GeneralName; end class UniformResourceIdentifier < GeneralName; end class Unknown < GeneralName; end end |
#other_name ⇒ Types::OtherName
Represents ‘GeneralName` using an `OtherName` object.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 |
# File 'lib/aws-sdk-acm/types.rb', line 1332 class GeneralName < Struct.new( :directory_name, :dns_name, :ip_address, :other_name, :registered_id, :rfc_822_name, :uniform_resource_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectoryName < GeneralName; end class DnsName < GeneralName; end class IpAddress < GeneralName; end class OtherName < GeneralName; end class RegisteredId < GeneralName; end class Rfc822Name < GeneralName; end class UniformResourceIdentifier < GeneralName; end class Unknown < GeneralName; end end |
#registered_id ⇒ String
Represents ‘GeneralName` as an object identifier (OID).
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 |
# File 'lib/aws-sdk-acm/types.rb', line 1332 class GeneralName < Struct.new( :directory_name, :dns_name, :ip_address, :other_name, :registered_id, :rfc_822_name, :uniform_resource_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectoryName < GeneralName; end class DnsName < GeneralName; end class IpAddress < GeneralName; end class OtherName < GeneralName; end class RegisteredId < GeneralName; end class Rfc822Name < GeneralName; end class UniformResourceIdentifier < GeneralName; end class Unknown < GeneralName; end end |
#rfc_822_name ⇒ String
Represents ‘GeneralName` as an [RFC 822] email address.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 |
# File 'lib/aws-sdk-acm/types.rb', line 1332 class GeneralName < Struct.new( :directory_name, :dns_name, :ip_address, :other_name, :registered_id, :rfc_822_name, :uniform_resource_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectoryName < GeneralName; end class DnsName < GeneralName; end class IpAddress < GeneralName; end class OtherName < GeneralName; end class RegisteredId < GeneralName; end class Rfc822Name < GeneralName; end class UniformResourceIdentifier < GeneralName; end class Unknown < GeneralName; end end |
#uniform_resource_identifier ⇒ String
Represents ‘GeneralName` as a URI.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 |
# File 'lib/aws-sdk-acm/types.rb', line 1332 class GeneralName < Struct.new( :directory_name, :dns_name, :ip_address, :other_name, :registered_id, :rfc_822_name, :uniform_resource_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectoryName < GeneralName; end class DnsName < GeneralName; end class IpAddress < GeneralName; end class OtherName < GeneralName; end class RegisteredId < GeneralName; end class Rfc822Name < GeneralName; end class UniformResourceIdentifier < GeneralName; end class Unknown < GeneralName; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1332 1333 1334 |
# File 'lib/aws-sdk-acm/types.rb', line 1332 def unknown @unknown end |