Class: Aws::ACM::Types::GetCertificateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::GetCertificateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate ⇒ String
The ACM-issued certificate corresponding to the ARN specified as input.
-
#certificate_chain ⇒ String
Certificates forming the requested certificate’s chain of trust.
Instance Attribute Details
#certificate ⇒ String
The ACM-issued certificate corresponding to the ARN specified as input.
1396 1397 1398 1399 1400 1401 |
# File 'lib/aws-sdk-acm/types.rb', line 1396 class GetCertificateResponse < Struct.new( :certificate, :certificate_chain) SENSITIVE = [] include Aws::Structure end |
#certificate_chain ⇒ String
Certificates forming the requested certificate’s chain of trust. The chain consists of the certificate of the issuing CA and the intermediate certificates of any other subordinate CAs.
1396 1397 1398 1399 1400 1401 |
# File 'lib/aws-sdk-acm/types.rb', line 1396 class GetCertificateResponse < Struct.new( :certificate, :certificate_chain) SENSITIVE = [] include Aws::Structure end |