Class: Aws::ACM::Types::ListCertificateDomainValidationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::ListCertificateDomainValidationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the certificate for which to list domain validation summaries.
-
#max_items ⇒ Integer
The maximum number of domain validation summaries to return.
-
#next_token ⇒ String
A token returned by a previous call to
ListCertificateDomainValidations.
Instance Attribute Details
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the certificate for which to list domain validation summaries.
2792 2793 2794 2795 2796 2797 2798 |
# File 'lib/aws-sdk-acm/types.rb', line 2792 class ListCertificateDomainValidationsRequest < Struct.new( :certificate_arn, :next_token, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of domain validation summaries to return. If you don't specify a value, the default is 1000.
2792 2793 2794 2795 2796 2797 2798 |
# File 'lib/aws-sdk-acm/types.rb', line 2792 class ListCertificateDomainValidationsRequest < Struct.new( :certificate_arn, :next_token, :max_items) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token returned by a previous call to
ListCertificateDomainValidations. If the number of results exceeds
MaxItems, use this token to retrieve the next page of results.
2792 2793 2794 2795 2796 2797 2798 |
# File 'lib/aws-sdk-acm/types.rb', line 2792 class ListCertificateDomainValidationsRequest < Struct.new( :certificate_arn, :next_token, :max_items) SENSITIVE = [] include Aws::Structure end |