Class: Aws::ACM::Types::ListCertificateDomainValidationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::ListCertificateDomainValidationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_validation_summary_list ⇒ Array<Types::DomainValidationSummary>
A list of DomainValidationSummary objects, one for each domain on the certificate.
-
#next_token ⇒ String
If the number of results exceeds
MaxItems, this token is included in the response.
Instance Attribute Details
#domain_validation_summary_list ⇒ Array<Types::DomainValidationSummary>
A list of DomainValidationSummary objects, one for each domain on the certificate. Each object contains the domain name and its active and requested validation configurations.
2815 2816 2817 2818 2819 2820 |
# File 'lib/aws-sdk-acm/types.rb', line 2815 class ListCertificateDomainValidationsResponse < Struct.new( :domain_validation_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the number of results exceeds MaxItems, this token is included
in the response. Use this token in a subsequent
ListCertificateDomainValidations request to retrieve the next page
of results.
2815 2816 2817 2818 2819 2820 |
# File 'lib/aws-sdk-acm/types.rb', line 2815 class ListCertificateDomainValidationsResponse < Struct.new( :domain_validation_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |