Class: Aws::ACM::Types::ListCertificatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::ListCertificatesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_key_pair_origins ⇒ Array<String>
Filter the certificate list by certificate key pair origin.
-
#certificate_statuses ⇒ Array<String>
Filter the certificate list by status value.
-
#includes ⇒ Types::Filters
Filter the certificate list.
-
#max_items ⇒ Integer
Use this parameter when paginating results to specify the maximum number of items to return in the response.
-
#next_token ⇒ String
Use this parameter only when paginating results and only in a subsequent request after you receive a response with truncated results.
-
#sort_by ⇒ String
Specifies the field to sort results by.
-
#sort_order ⇒ String
Specifies the order of sorted results.
Instance Attribute Details
#certificate_key_pair_origins ⇒ Array<String>
Filter the certificate list by certificate key pair origin. Specify
one or more CertificateKeyPairOrigin values. Default filtering
returns only certificates with key pair origin of AWS_MANAGED and
CUSTOMER_PROVIDED.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 |
# File 'lib/aws-sdk-acm/types.rb', line 2865 class ListCertificatesRequest < Struct.new( :certificate_statuses, :certificate_key_pair_origins, :includes, :next_token, :max_items, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#certificate_statuses ⇒ Array<String>
Filter the certificate list by status value.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 |
# File 'lib/aws-sdk-acm/types.rb', line 2865 class ListCertificatesRequest < Struct.new( :certificate_statuses, :certificate_key_pair_origins, :includes, :next_token, :max_items, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#includes ⇒ Types::Filters
Filter the certificate list. For more information, see the Filters structure.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 |
# File 'lib/aws-sdk-acm/types.rb', line 2865 class ListCertificatesRequest < Struct.new( :certificate_statuses, :certificate_key_pair_origins, :includes, :next_token, :max_items, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
Use this parameter when paginating results to specify the maximum
number of items to return in the response. If additional items exist
beyond the number you specify, the NextToken element is sent in
the response. Use this NextToken value in a subsequent request to
retrieve additional items.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 |
# File 'lib/aws-sdk-acm/types.rb', line 2865 class ListCertificatesRequest < Struct.new( :certificate_statuses, :certificate_key_pair_origins, :includes, :next_token, :max_items, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Use this parameter only when paginating results and only in a
subsequent request after you receive a response with truncated
results. Set it to the value of NextToken from the response you
just received.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 |
# File 'lib/aws-sdk-acm/types.rb', line 2865 class ListCertificatesRequest < Struct.new( :certificate_statuses, :certificate_key_pair_origins, :includes, :next_token, :max_items, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
Specifies the field to sort results by. If you specify SortBy, you
must also specify SortOrder.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 |
# File 'lib/aws-sdk-acm/types.rb', line 2865 class ListCertificatesRequest < Struct.new( :certificate_statuses, :certificate_key_pair_origins, :includes, :next_token, :max_items, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Specifies the order of sorted results. If you specify SortOrder,
you must also specify SortBy.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 |
# File 'lib/aws-sdk-acm/types.rb', line 2865 class ListCertificatesRequest < Struct.new( :certificate_statuses, :certificate_key_pair_origins, :includes, :next_token, :max_items, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |