Class: Aws::ACM::Types::SearchCertificatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::SearchCertificatesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter_statement ⇒ Types::CertificateFilterStatement
A filter statement that defines the search criteria.
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
Use this parameter only when paginating results and only in a subsequent request after you receive a response with truncated results.
-
#sort_by ⇒ String
Specifies the field to sort results by.
-
#sort_order ⇒ String
Specifies the order of sorted results.
Instance Attribute Details
#filter_statement ⇒ Types::CertificateFilterStatement
A filter statement that defines the search criteria. You can combine multiple filters using AND, OR, and NOT logical operators to create complex queries.
3400 3401 3402 3403 3404 3405 3406 3407 3408 |
# File 'lib/aws-sdk-acm/types.rb', line 3400 class SearchCertificatesRequest < Struct.new( :filter_statement, :max_results, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in the response. Default is 100.
3400 3401 3402 3403 3404 3405 3406 3407 3408 |
# File 'lib/aws-sdk-acm/types.rb', line 3400 class SearchCertificatesRequest < Struct.new( :filter_statement, :max_results, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Use this parameter only when paginating results and only in a
subsequent request after you receive a response with truncated
results. Set it to the value of NextToken from the response you
just received.
3400 3401 3402 3403 3404 3405 3406 3407 3408 |
# File 'lib/aws-sdk-acm/types.rb', line 3400 class SearchCertificatesRequest < Struct.new( :filter_statement, :max_results, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
Specifies the field to sort results by. Valid values are CREATED_AT, NOT_AFTER, STATUS, RENEWAL_STATUS, EXPORTED, IN_USE, NOT_BEFORE, KEY_ALGORITHM, TYPE, CERTIFICATE_ARN, COMMON_NAME, REVOKED_AT, RENEWAL_ELIGIBILITY, ISSUED_AT, MANAGED_BY, EXPORT_OPTION, VALIDATION_METHOD, and IMPORTED_AT.
3400 3401 3402 3403 3404 3405 3406 3407 3408 |
# File 'lib/aws-sdk-acm/types.rb', line 3400 class SearchCertificatesRequest < Struct.new( :filter_statement, :max_results, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Specifies the order of sorted results. Valid values are ASCENDING or DESCENDING.
3400 3401 3402 3403 3404 3405 3406 3407 3408 |
# File 'lib/aws-sdk-acm/types.rb', line 3400 class SearchCertificatesRequest < Struct.new( :filter_statement, :max_results, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |