Class: Aws::ACM::Types::SearchCertificatesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filter_statementTypes::CertificateFilterStatement

A filter statement that defines the search criteria. You can combine multiple filters using AND, OR, and NOT logical operators to create complex queries.



2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'lib/aws-sdk-acm/types.rb', line 2207

class SearchCertificatesRequest < Struct.new(
  :filter_statement,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in the response. Default is 100.

Returns:

  • (Integer)


2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'lib/aws-sdk-acm/types.rb', line 2207

class SearchCertificatesRequest < Struct.new(
  :filter_statement,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Use this parameter only when paginating results and only in a subsequent request after you receive a response with truncated results. Set it to the value of ‘NextToken` from the response you just received.

Returns:

  • (String)


2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'lib/aws-sdk-acm/types.rb', line 2207

class SearchCertificatesRequest < Struct.new(
  :filter_statement,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

Specifies the field to sort results by. Valid values are CREATED_AT, NOT_AFTER, STATUS, RENEWAL_STATUS, EXPORTED, IN_USE, NOT_BEFORE, KEY_ALGORITHM, TYPE, CERTIFICATE_ARN, COMMON_NAME, REVOKED_AT, RENEWAL_ELIGIBILITY, ISSUED_AT, MANAGED_BY, EXPORT_OPTION, VALIDATION_METHOD, and IMPORTED_AT.

Returns:

  • (String)


2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'lib/aws-sdk-acm/types.rb', line 2207

class SearchCertificatesRequest < Struct.new(
  :filter_statement,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

Specifies the order of sorted results. Valid values are ASCENDING or DESCENDING.

Returns:

  • (String)


2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'lib/aws-sdk-acm/types.rb', line 2207

class SearchCertificatesRequest < Struct.new(
  :filter_statement,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end