Class: Aws::ACM::Types::UpdateCertificateOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::UpdateCertificateOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
ARN of the requested certificate to update.
-
#options ⇒ Types::CertificateOptions
Use to update the options for your certificate.
Instance Attribute Details
#certificate_arn ⇒ String
ARN of the requested certificate to update. This must be of the form:
arn:aws:acm:us-east-1:account:certificate/12345678-1234-1234-1234-123456789012
3844 3845 3846 3847 3848 3849 |
# File 'lib/aws-sdk-acm/types.rb', line 3844 class UpdateCertificateOptionsRequest < Struct.new( :certificate_arn, :options) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Types::CertificateOptions
Use to update the options for your certificate. Currently, you can change the domain validation method or specify whether to export your certificate. For more information about migrating from email to DNS validation, see Migrate from email to DNS validation.
3844 3845 3846 3847 3848 3849 |
# File 'lib/aws-sdk-acm/types.rb', line 3844 class UpdateCertificateOptionsRequest < Struct.new( :certificate_arn, :options) SENSITIVE = [] include Aws::Structure end |