Class: Aws::ACM::Types::UpdateCertificateOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACM::Types::UpdateCertificateOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
ARN of the requested certificate to update.
-
#options ⇒ Types::CertificateOptions
Use to update the options for your certificate.
Instance Attribute Details
#certificate_arn ⇒ String
ARN of the requested certificate to update. This must be of the form:
arn:aws:acm:us-east-1:account:certificate/12345678-1234-1234-1234-123456789012
3690 3691 3692 3693 3694 3695 |
# File 'lib/aws-sdk-acm/types.rb', line 3690 class UpdateCertificateOptionsRequest < Struct.new( :certificate_arn, :options) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Types::CertificateOptions
Use to update the options for your certificate. Currently, you can specify whether to export your certificate. Certificate transparency logging opt-out is no longer available. All public certificates are recorded in a certificate transparency log. For more information, see Certificate Transparency Logging.
3690 3691 3692 3693 3694 3695 |
# File 'lib/aws-sdk-acm/types.rb', line 3690 class UpdateCertificateOptionsRequest < Struct.new( :certificate_arn, :options) SENSITIVE = [] include Aws::Structure end |