Class: Aws::ACM::Types::UpdateCertificateOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-acm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_arnString

ARN of the requested certificate to update. This must be of the form:

‘arn:aws:acm:us-east-1:account:certificate/12345678-1234-1234-1234-123456789012 `

Returns:

  • (String)


2405
2406
2407
2408
2409
2410
# File 'lib/aws-sdk-acm/types.rb', line 2405

class UpdateCertificateOptionsRequest < Struct.new(
  :certificate_arn,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::CertificateOptions

Use to update the options for your certificate. Currently, you can specify whether to export your certificate. Certificate transparency logging opt-out is no longer available. All public certificates are recorded in a certificate transparency log. For more information, see [Certificate Transparency Logging].

[1]: docs.aws.amazon.com/acm/latest/userguide/acm-concepts.html#concept-transparency



2405
2406
2407
2408
2409
2410
# File 'lib/aws-sdk-acm/types.rb', line 2405

class UpdateCertificateOptionsRequest < Struct.new(
  :certificate_arn,
  :options)
  SENSITIVE = []
  include Aws::Structure
end